AdaptiveUIUX class

Main entry point for the Adaptive UI UX package

Constructors

AdaptiveUIUX()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

config AdaptiveConfig
The configuration for the adaptive UI
getter/setter pair

Static Methods

init({AdaptiveConfig? customConfig}) Future<void>
Initialize the adaptive UI
reset() Future<void>
Reset all adaptive UI data and configurations