StorageBackend class abstract

Interface for all storage backends

Implementers

Constructors

StorageBackend()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearInteractionEvents() Future<bool>
Clear all interaction events
deleteLayoutConfig(String id) Future<bool>
Delete a layout configuration
getAllInteractionEvents() Future<List<InteractionEvent>>
Get all interaction events
getAllLayoutConfigs() Future<List<LayoutConfig>>
Get all layout configurations
getInteractionEvents(String widgetId) Future<List<InteractionEvent>>
Get all interaction events for a widget
getLayoutConfig(String id) Future<LayoutConfig?>
Get a layout configuration by ID
logInteractionEvent(InteractionEvent event) Future<bool>
Log an interaction event
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveLayoutConfig(LayoutConfig config) Future<bool>
Save a layout configuration
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited