WidgetPosition class

Stores position and configuration of a widget in an adaptive layout

Constructors

WidgetPosition({required String widgetId, required int order, BoxConstraints? constraints, bool visible = true})
Constructor for creating a new widget position
WidgetPosition.fromJson(Map<String, dynamic> json)
Create a widget position from a JSON map
factory

Properties

constraints BoxConstraints?
Optional constraints for the widget
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
order int
Position order in the layout (lower numbers come first)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visible bool
Optional visibility flag
getter/setter pair
widgetId String
Unique identifier for the widget
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert the widget position to a JSON map
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited