HighlightOutliersRule class
A rule that highlights widgets with anomalously high usage
- Implemented types
Constructors
- HighlightOutliersRule({double threshold = 2.0})
Properties
Methods
-
apply(
Map< String, int> interactionCounts) → List<String> -
Apply the rule to the analysis result
Returns a list of widgets in their recommended order
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited