RuleEngine class

Class for analyzing widget usage and suggesting layout changes

Constructors

RuleEngine({InteractionTracker? tracker, LayoutStore? layoutStore, List<LayoutRule>? rules, int minInteractions = 5})
Create a new rule engine

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRule(LayoutRule rule) → void
Add a rule to the engine
clearRules() → void
Clear all rules
evaluateAndApplyRules() Future<bool>
Evaluate rules and apply the results to the current layout
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeRule(LayoutRule rule) → void
Remove a rule from the engine
setRules(List<LayoutRule> rules) → void
Set the rules for the engine
startAutoAdjustments({Duration interval = const Duration(seconds: 30)}) → void
Start automatic layout adjustments
stopAutoAdjustments() → void
Stop automatic layout adjustments
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited