AdaptiveConfig class
Configuration options for the adaptive UI
Constructors
- AdaptiveConfig({int threshold = 10, LayoutMode layoutMode = LayoutMode.stacked, bool enableAutoAdjust = true, bool enableDebugLogging = false})
-
Constructor
const
Properties
- enableAutoAdjust → bool
-
Whether to enable automatic adjustments
final
- enableDebugLogging → bool
-
Whether to log interactions to console (debug mode)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- layoutMode → LayoutMode
-
The layout mode to use
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- threshold → int
-
The threshold number of interactions before adapting the layout
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited