LocalStorageBackend class
Local storage implementation using SharedPreferences
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearInteractionEvents(
) → Future< bool> -
Clear all interaction events
override
-
deleteLayoutConfig(
String id) → Future< bool> -
Delete a layout configuration
override
-
getAllInteractionEvents(
) → Future< List< InteractionEvent> > -
Get all interaction events
override
-
getAllLayoutConfigs(
) → Future< List< LayoutConfig> > -
Get all layout configurations
override
-
getInteractionEvents(
String widgetId) → Future< List< InteractionEvent> > -
Get all interaction events for a widget
override
-
getLayoutConfig(
String id) → Future< LayoutConfig?> -
Get a layout configuration by ID
override
-
initialize(
) → Future< void> - Initialize the local storage
-
logInteractionEvent(
InteractionEvent event) → Future< bool> -
Log an interaction event
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saveLayoutConfig(
LayoutConfig config) → Future< bool> -
Save a layout configuration
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited