LayoutStore class
Manages layout configurations for adaptive layouts
- Inheritance
-
- Object
- ChangeNotifier
- LayoutStore
Constructors
- LayoutStore({StorageBackend? storage})
-
Factory constructor that accepts a custom storage backend
factory
Properties
- currentLayout → LayoutConfig?
-
Current active layout configuration
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
-
onLayoutChange
→ Stream<
LayoutConfig> -
Stream of layout changes
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
createLayout(
{required String name, List< WidgetPosition> ? initialPositions}) → Future<LayoutConfig> - Create a new layout configuration
-
deleteLayout(
String id) → Future< void> - Delete a layout configuration
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
override
-
getAllLayouts(
) → Future< List< LayoutConfig> > - Get all layout configurations
-
getLayout(
String id) → Future< LayoutConfig?> - Get a layout configuration by ID
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
removeWidgetPosition(
String widgetId) → Future< void> - Remove a widget position from the current layout
-
reorderWidgets(
List< String> widgetIds) → Future<void> - Reorder widget positions in the current layout
-
setCurrentLayout(
String id) → Future< void> - Set the current active layout
-
toString(
) → String -
A string representation of this object.
inherited
-
updateWidgetPosition(
WidgetPosition position) → Future< void> - Update a widget position in the current layout
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → LayoutStore
-
Get the singleton instance of the layout store
no setter