LayoutConfig class
Configuration for an adaptive layout
Constructors
-
LayoutConfig({required String id, required String name, required List<
WidgetPosition> positions, DateTime? lastModified}) - Constructor for creating a new layout configuration
-
LayoutConfig.fromJson(Map<
String, dynamic> json) -
Create a layout config from a JSON map
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier for the layout
final
- lastModified ↔ DateTime
-
Last time the layout was modified
getter/setter pair
- name → String
-
Name of the layout
final
-
positions
→ List<
WidgetPosition> -
Layout positions for all widgets
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert the layout config to a JSON map
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited